summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/private/kopeteemoticons.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/private/kopeteemoticons.h')
-rw-r--r--kopete/libkopete/private/kopeteemoticons.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kopete/libkopete/private/kopeteemoticons.h b/kopete/libkopete/private/kopeteemoticons.h
index 84fd305a..762a02a0 100644
--- a/kopete/libkopete/private/kopeteemoticons.h
+++ b/kopete/libkopete/private/kopeteemoticons.h
@@ -18,9 +18,9 @@
#ifndef kopeteemoticons_h__
#define kopeteemoticons_h__
-#include <qobject.h>
-#include <qvaluelist.h>
-#include <qregexp.h>
+#include <tqobject.h>
+#include <tqvaluelist.h>
+#include <tqregexp.h>
#include "kopete_export.h"
@@ -35,7 +35,7 @@ public:
* chosen by the user.
* Instead, use @ref Kopete::Emoticons::self()
**/
- Emoticons( const QString &theme = QString::null );
+ Emoticons( const TQString &theme = TQString::null );
~Emoticons( );
@@ -63,10 +63,10 @@ public:
* If nicks is provided, they will not be parsed if they
* exist in message.
*/
- static QString parseEmoticons( const QString &message, ParseMode = SkipHTML ) ;
+ static TQString parseEmoticons( const TQString &message, ParseMode = SkipHTML ) ;
- QString parse( const QString &message, ParseMode = SkipHTML );
+ TQString parse( const TQString &message, ParseMode = SkipHTML );
/**
* TokenType, a token might be an image ( emoticon ) or text.
@@ -77,15 +77,15 @@ public:
};
/**
* A token consists of a QString text which is either a regular text
* or a path to image depending on the type.
* If type is Image the text refers to an image path.
* If type is Text the text refers to a regular text.
*/
struct Token {
Token() : type( Undefined ) {}
- Token( TokenType t, const QString &m ) : type( t ), text(m) {}
- Token( TokenType t, const QString &m, const QString &p, const QString &html )
+ Token( TokenType t, const TQString &m ) : type( t ), text(m) {}
+ Token( TokenType t, const TQString &m, const TQString &p, const TQString &html )
: type( t ), text( m ), picPath( p ), picHTMLCode( html ) {}
TokenType type;
QString text;
@@ -96,9 +96,9 @@ public:
/**
* Static function which will call tokenize
- * @see tokenize( const QString& )
+ * @see tokenize( const TQString& )
*/
- static QValueList<Token> tokenizeEmoticons( const QString &message, ParseMode mode = DefaultParseMode );
+ static TQValueList<Token> tokenizeEmoticons( const TQString &message, ParseMode mode = DefaultParseMode );
/**
* Tokenizes an message.
@@ -120,17 +120,17 @@ public:
* Note: quotation marks are used to emphasize white spaces.
* @param message is the message to tokenize
* @param mode is a bitmask of ParseMode enum
* @return a QValueList which consiste of ordered tokens of the text.
* @author Engin AYDOGAN < engin@bzzzt.biz >
* @since 23-03-05
*/
- QValueList<Token> tokenize( const QString &message, uint mode = DefaultParseMode );
+ TQValueList<Token> tokenize( const TQString &message, uint mode = DefaultParseMode );
/**
* Return all emoticons and the corresponding icon.
* (only one emoticon per image)
*/
- QMap<QString, QStringList> emoticonAndPicList();
+ TQMap<TQString, TQStringList> emoticonAndPicList();
public slots:
/**
@@ -149,19 +149,19 @@ private:
* add an emoticon to our mapping if
* an animation/pixmap has been found for it
**/
- void addIfPossible( const QString& filenameNoExt, const QStringList &emoticons );
+ void addIfPossible( const TQString& filenameNoExt, const TQStringList &emoticons );
/**
* uses the kopete's emoticons.xml for the theme
* @see initEmoticons
*/
- void initEmoticon_emoticonsxml( const QString & filename);
+ void initEmoticon_emoticonsxml( const TQString & filename);
/**
* uses the JEP-0038 xml description for the theme
* @see initEmoticons
*/
- void initEmoticon_JEP0038( const QString & filename);
+ void initEmoticon_JEP0038( const TQString & filename);
/**
* sorts emoticons for convenient parsing, which yields greedy matching on
@@ -180,7 +180,7 @@ private slots:
* Fills the map with paths and emoticons
* This needs to be done on every emoticon-theme change
**/
- void initEmoticons ( const QString &theme = QString::null );
+ void initEmoticons ( const TQString &theme = TQString::null );
};
@@ -77,15 +77,15 @@ public:
};
/**
- * A token consists of a QString text which is either a regular text
+ * A token consists of a TQString text which is either a regular text
* or a path to image depending on the type.
* If type is Image the text refers to an image path.
@@ -120,17 +120,17 @@ public:
* @param message is the message to tokenize
* @param mode is a bitmask of ParseMode enum
- * @return a QValueList which consiste of ordered tokens of the text.
+ * @return a TQValueList which consiste of ordered tokens of the text.
* @author Engin AYDOGAN < engin@bzzzt.biz >
* @since 23-03-05